@@ -1,4 +1,17 @@
-# from __future__ import absolute_import
+"""
+This code was originally published by the following individuals for use with
+Scilab:
+    Copyright (C) 2012 - 2013 - Michael Baudin
+    Copyright (C) 2012 - Maria Christopoulou
+    Copyright (C) 2010 - 2011 - INRIA - Michael Baudin
+    Copyright (C) 2009 - Yann Collette
+    Copyright (C) 2009 - CEA - Jean-Marc Martinez
+    
+    website: forge.scilab.org/index.php/p/scidoe/sourcetree/master/macros
+
+Much thanks goes to these individuals. It has been converted to Python by 
+Abraham Lee.
+"""
 
 import numpy as np
 from pyDOE.doe_factorial import ff2n
